==> cvxpy-0.1.tar.gz: cvxpy-0.1/cvxpy/expressions/types.py <==
"""
Copyright 2013 Steven Diamond

This file is part of CVXPY.

CVXPY is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CVXPY is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
"""

# Utility functions to solve circular imports.
def constant():
    import constants
    return constants.Constant

def variable():
    import variables
    return variables.Variable

def parameter():
    import constants
    return constants.Parameter

def expression():
    import expression
    return expression.Expression

def add_expr():
    from ..atoms.affine import add_expr
    return add_expr.AddExpression

def mul_expr():
    from ..atoms.affine import binary_operators
    return binary_operators.MulExpression

def div_expr():
    from ..atoms.affine import binary_operators
    return binary_operators.DivExpression

def neg_expr():
    from ..atoms.affine import unary_operators
    return unary_operators.NegExpression

def index():
    from ..atoms.affine import index
    return index.index

def transpose():
    from ..atoms.affine import transpose
    return transpose.transpose

==> cvxpy-0.2.15.tar.gz: cvxpy-0.2.15/cvxpy/expressions/types.py <==
"""
Copyright 2013 Steven Diamond

This file is part of CVXPY.

CVXPY is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CVXPY is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
"""

# Utility functions to solve circular imports.
def constant():
    import constants
    return constants.Constant

def add_expr():
    from cvxpy.atoms.affine import add_expr
    return add_expr.AddExpression

def mul_expr():
    from cvxpy.atoms.affine import binary_operators
    return binary_operators.MulExpression

def div_expr():
    from cvxpy.atoms.affine import binary_operators
    return binary_operators.DivExpression

def neg_expr():
    from cvxpy.atoms.affine import unary_operators
    return unary_operators.NegExpression

def index():
    from cvxpy.atoms.affine import index
    return index.index

def transpose():
    from cvxpy.atoms.affine import transpose
    return transpose.transpose

def inv_pos():
    from cvxpy.atoms.elementwise import inv_pos
    return inv_pos.inv_pos

def square():
    from cvxpy.atoms.elementwise import square
    return square.square

def sqrt():
    from cvxpy.atoms.elementwise import sqrt
    return sqrt.sqrt
